@@ -73,16 +73,25 @@ namespace opensaml {
          * @param role              identifies the role (generally IdP or SP) of the policy peer
          * @param trustEngine       TrustEngine to authenticate policy peer
          * @param validate          true iff XML parsing should be done with validation
+         * @param profile           profile identifier
          */
         SecurityPolicy(
             const saml2md::MetadataProvider* metadataProvider=nullptr,
             const xmltooling::QName* role=nullptr,
             const xmltooling::TrustEngine* trustEngine=nullptr,
-            bool validate=true
+            bool validate=true,
+            const char* profile=nullptr
             );
 
         virtual ~SecurityPolicy();
 
+        /**
+         * Returns the profile identifier associated with the transaction.
+         *
+         * @return the profile identifier
+         */
+        const char* getProfile() const;
+
         /**
          * Returns the locked MetadataProvider supplied to the policy.
          *
@@ -158,6 +167,14 @@ namespace opensaml {
          */
         const XMLCh* getCorrelationID() const;
 
+        /**
+        * Returns the message identifier to which the message being evaluated
+        * claims to be a response.
+        *
+        * @return correlatable message identifier
+        */
+        const XMLCh* getInResponseTo() const;
+
         /**
          * Gets a mutable array of installed policy rules.
          *
@@ -167,6 +184,13 @@ namespace opensaml {
          */
         std::vector<const SecurityPolicyRule*>& getRules();
 
+        /**
+        * Sets the profile identifier associated with the transaction.
+        *
+        * @param id the profile identifier
+        */
+        void setProfile(const char* id);
+
         /**
          * Sets a locked MetadataProvider for the policy.
          *
@@ -233,6 +257,14 @@ namespace opensaml {
          */
         void setCorrelationID(const XMLCh* correlationID);
 
+        /**
+        * Sets the message identifier to which the message being evaluated
+        * was responding (i.e., the value to be compared to the correlation ID).
+        *
+        * @param id correlatable message identifier
+        */
+        void setInResponseTo(const XMLCh* id);
+
         /**
          * Evaluates the policy against the given request and message,
          * possibly populating message information in the policy object.
@@ -401,7 +433,7 @@ namespace opensaml {
 
     private:
         // information extracted from message
-        xmltooling::xstring m_messageID;
+        xmltooling::xstring m_messageID, m_correlationID, m_inResponseTo;
         time_t m_issueInstant;
         boost::scoped_ptr<saml2::Issuer> m_issuer;
         const saml2md::RoleDescriptor* m_issuerRole;
@@ -417,8 +449,8 @@ namespace opensaml {
         bool m_entityOnly;
 
         // contextual information
+        std::string m_profile;
         mutable time_t m_ts;
-        xmltooling::xstring m_correlationID;
         std::vector<xmltooling::xstring> m_audiences;
     };
 
