@@ -56,7 +56,7 @@ const XMLCh* SAML1MessageDecoder::getProtocolFamily() const
 }
 
 void SAML1MessageDecoder::extractMessageDetails(
-    const XMLObject& message, const GenericRequest& req, const XMLCh* protocol, SecurityPolicy& policy
+    const XMLObject& message, const GenericRequest&, const XMLCh* protocol, SecurityPolicy& policy
     ) const
 {
     // Only handle SAML 1.x protocol messages.
