@@ -85,10 +85,10 @@ namespace opensaml {
 long SAML1SOAPEncoder::encode(
     GenericResponse& genericResponse,
     XMLObject* xmlObject,
-    const char* destination,
-    const EntityDescriptor* recipient,
-    const char* relayState,
-    const ArtifactGenerator* artifactGenerator,
+    const char*,
+    const EntityDescriptor*,
+    const char*,
+    const ArtifactGenerator*,
     const Credential* credential,
     const XMLCh* signatureAlg,
     const XMLCh* digestAlg
