@@ -68,7 +68,7 @@ SAML2ArtifactType0004::SAML2ArtifactType0004(const string& sourceid, int index)
     m_raw.append(sourceid,0,SOURCEID_LENGTH);
     char buf[HANDLE_LENGTH];
     SAMLConfig::getConfig().generateRandomBytes(buf,HANDLE_LENGTH);
-    for (int i=0; i<HANDLE_LENGTH; i++)
+    for (unsigned int i=0; i<HANDLE_LENGTH; i++)
         m_raw+=buf[i];
 }
 
