@@ -86,7 +86,7 @@ XMLObject* SAML2SOAPDecoder::decode(
 
     log.debug("validating input");
     string s = genericRequest.getContentType();
-    if (s.find("text/xml") == string::npos) {
+    if (s.find("text/xml") == string::npos || s.find("application/x-www-form-urlencoded") != string::npos) {
         log.warn("ignoring incorrect content type (%s)", s.c_str() ? s.c_str() : "none");
         throw BindingException("Invalid content type for SOAP message.");
     }
