@@ -60,7 +60,7 @@ namespace opensaml {
         static const XMLCh _type[] =                UNICODE_LITERAL_4(t,y,p,e);
         static const XMLCh _XML[] =                 UNICODE_LITERAL_3(X,M,L);
     
-        static void FolderCallback(const char* pathname, struct stat& stat_buf, void* data) {
+        static void FolderCallback(const char* pathname, struct stat&, void* data) {
             // data is a pair of DOM elements, the config root and the mocked up Chaining child
             pair<const DOMElement*,DOMElement*>* p = reinterpret_cast<pair<const DOMElement*,DOMElement*>*>(data);
             auto_ptr_XMLCh entry(pathname);
