@@ -208,7 +208,7 @@ void MetadataProvider::doFilters(const MetadataFilterContext* ctx, XMLObject& xm
     }
 }
 
-void MetadataProvider::outputStatus(ostream& os) const
+void MetadataProvider::outputStatus(ostream&) const
 {
 }
 
