@@ -41,7 +41,7 @@ namespace opensaml {
         class SAML_DLLLOCAL NullMetadataProvider : public AbstractDynamicMetadataProvider
         {
         public:
-            NullMetadataProvider(const DOMElement* e) : AbstractDynamicMetadataProvider(true, e), MetadataProvider(e) {
+            NullMetadataProvider(const DOMElement* e) : MetadataProvider(e), AbstractDynamicMetadataProvider(true, e) {
                 e = XMLHelper::getFirstChildElement(e, samlconstants::SAML20MD_NS, EntityDescriptor::LOCAL_NAME);
                 if (e)
                     m_template.reset(dynamic_cast<EntityDescriptor*>(XMLObjectBuilder::buildOneFromElement(const_cast<DOMElement*>(e))));
@@ -58,14 +58,14 @@ namespace opensaml {
             scoped_ptr<EntityDescriptor> m_template;
         }; 
 
-        MetadataProvider* SAML_DLLLOCAL NullMetadataProviderFactory(const DOMElement* const & e, bool deprecationSupport)
+        MetadataProvider* SAML_DLLLOCAL NullMetadataProviderFactory(const DOMElement* const & e, bool)
         {
             return new NullMetadataProvider(e);
         }
     };
 };
 
-EntityDescriptor* NullMetadataProvider::resolve(const MetadataProvider::Criteria& criteria, string& cacheTag) const
+EntityDescriptor* NullMetadataProvider::resolve(const MetadataProvider::Criteria& criteria, string&) const
 {
     // Resolving for us just means fabricating a new dummy element.
     EntityDescriptor* entity = m_template.get() ? m_template->cloneEntityDescriptor() : EntityDescriptorBuilder::buildEntityDescriptor();
