@@ -112,9 +112,9 @@ public:
     Lockable* lock() {return this;}
     void unlock() {}
 
-    const Credential* resolve(const CredentialCriteria* criteria=nullptr) const {return nullptr;}
+    const Credential* resolve(const CredentialCriteria*) const {return nullptr;}
     vector<const Credential*>::size_type resolve(
-        vector<const Credential*>& results, const CredentialCriteria* criteria=nullptr
+        vector<const Credential*>&, const CredentialCriteria*
         ) const {return 0;}
 };
 
