@@ -126,7 +126,7 @@ protected:
     }
 
     void skipNetworked() {
-        if (getenv("SAMLTEST_SKIP_NETWORKED")) {
+        if (!getenv("SAMLTEST_NETWORKED")) {
 #ifdef TS_SKIP
             TS_SKIP("requires network access");
 #endif
